image_io_index = [
  'png',
  'meta',
  'tiff',
  'nifti',
  'jpeg',
  'nrrd',
  'vtk',
  'bmp',
  'hdf5',
  'minc',
  'mrc',
  'lsm',
  'mgh',
  'bio_rad',
  'gipl',
  'ge_adw',
  'ge4',
  'ge5',
  'gdcm',
  'scanco',
  'wasm',
  'wasm_zstd',
]

